@@ -12,7 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Provides preprocessing utilities."""
+from typing import Any  # noqa # pylint: disable=unused-import
 from typing import Optional, Sequence, Tuple, Union
+import warnings
 
 import tensorflow as tf
 
@@ -21,11 +23,12 @@ class RgbToBgr(tf.keras.layers.Layer):
     """A Keras pre-processing layer that converts RGB inputs to BGR color representation."""
 
     @tf.function
-    def call(self, inputs: tf.Tensor) -> tf.Tensor:
+    def call(self, inputs: 'tf.Tensor', **kwargs: 'Any') -> 'tf.Tensor':
         """Performs the RGB to BGR conversion.
 
         Args:
             inputs: The RGB image.
+            kwargs: Additional keyword arguments.
 
         Returns:
             The BGR image.
@@ -38,30 +41,32 @@ class RgbaToBgra(tf.keras.layers.Layer):
     """A Keras pre-processing layer that converts RGBA inputs to BGRA color representation."""
 
     @tf.function
-    def call(self, inputs: tf.Tensor) -> tf.Tensor:
+    def call(self, inputs: 'tf.Tensor', **kwargs: 'Any') -> 'tf.Tensor':
         """Performs the RGBA to BGRA conversion.
 
         Args:
             inputs: The RGBA image.
+            kwargs: Additional keyword arguments.
 
         Returns:
             The BGRA image.
         """
         # pylint: disable=no-self-use
-        return tf.concat([inputs[..., :-1][..., ::-1], inputs[..., -1:]], axis=-1)
+        return tf.concat([inputs[..., :-1][..., ::-1], inputs[..., -1:]], -1)
 
 
 class PerImageStandardization(tf.keras.layers.Layer):
     """A Keras pre-processing layer that applies per image standardization."""
 
     @tf.function
-    def call(self, inputs: tf.Tensor) -> tf.Tensor:
+    def call(self, inputs: 'tf.Tensor', **kwargs: 'Any') -> 'tf.Tensor':
         """Shifts and linearly scales each image.
 
          The image will have mean 0 and variance 1. The image is implicitly converted to float representation.
 
         Args:
             inputs: The image(s) to be standardized.
+            kwargs: Additional keyword arguments.
 
         Returns:
             The standardized image.
@@ -73,13 +78,44 @@ class PerImageStandardization(tf.keras.layers.Layer):
         return tf.image.per_image_standardization(inputs)
 
 
+class Normalization(tf.keras.layers.Layer):
+    """A Keras pre-processing layer that shifts the data to zero mean and standard deviation 1."""
+    def __init__(self, mean: Tuple[float, ...], std: Tuple[float, ...], *args: 'Any', **kwargs: 'Any') -> None:
+        """Creates an instance of the normalization layer.
+
+        Args:
+            mean: The mean of the dataset.
+            std: The standard deviation of the dataset.
+            args: Additional arguments to be passed to the base Layer class.
+            kwargs: Additional keyword arguments to be passed to the base Layer class.
+        """
+        super().__init__(*args, **kwargs)
+        self._mean = tf.convert_to_tensor(mean)
+        self._std = tf.convert_to_tensor(std)
+        if tf.reduce_any(self._std == 0):
+            warnings.warn("The defined standard deviation contains zeros. This may lead to numerical issues.")
+
+    @tf.function
+    def call(self, inputs: 'tf.Tensor', **kwargs: 'Any') -> 'tf.Tensor':
+        """Shifts and linearly scales an image by constant values.
+
+        Args:
+            inputs: The image(s) to be normalized.
+            kwargs: Additional keyword arguments.
+
+        Returns:
+            The normalized image.
+        """
+        return (inputs - tf.cast(self._mean, inputs.dtype)) / tf.cast(self._std, inputs.dtype)
+
+
 DEFAULT_LAYER = RgbToBgr()
 
 
-def add_preprocessing_layers(model: tf.keras.Model,
-                             layers: Optional[Union[tf.keras.layers.Layer,
-                                                    Sequence[tf.keras.layers.Layer]]] = DEFAULT_LAYER,
-                             spatial_dims: Optional[Tuple[int, int]] = None) -> tf.keras.Model:
+def add_preprocessing_layers(model: 'tf.keras.Model',
+                             layers: Optional[Union['tf.keras.layers.Layer',
+                                                    Sequence['tf.keras.layers.Layer']]] = DEFAULT_LAYER,
+                             spatial_dims: Optional[Tuple['int', 'int']] = None) -> 'tf.keras.Model':
     """Prepends a given pre-processing layer to a given Keras model.
 
     Args:
